@@ -10,12 +10,12 @@
 
 #include <cdescent.h>
 
-/* penalty term for s-lasso */
+/*** 1D derivation operator for the L2 penalty of s-lasso ***/
 
 static mm_sparse *
 penalty_ssmooth (const int n)
 {
-	int		i, j, k;
+	int			j, k;
 	mm_sparse	*s = mm_real_new (MM_REAL_SPARSE, MM_REAL_GENERAL, n - 1, n, 2 * (n - 1));
 
 	k = 0;
@@ -46,7 +46,7 @@ penalty_dsmooth (const int n)
 	return d;
 }
 
-/* s-lasso */
+/*** sparse/dense 1D derivation operator ***/
 mm_real *
 penalty_smooth (MMRealFormat format, const int n)
 {
